==> jc-1.4.0.tar.gz: polyglot/util/NestedMap__24EntrySet.h <==
// final class polyglot.util.NestedMap$EntrySet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class 2a538e5e1e2cef04 polyglot_util_NestedMap__24EntrySet

// header file dependencies
// @dep_header java_util_AbstractSet

#include "java/util/AbstractSet.h"

#ifndef _JC_polyglot_util_NestedMap__24EntrySet_H_
#define _JC_polyglot_util_NestedMap__24EntrySet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;
struct _jc_polyglot_util_NestedMap$object;
struct _jc_polyglot_util_NestedMap__241$object;

// Typedefs
typedef struct _jc_polyglot_util_NestedMap__24EntrySet$sub_refs	_jc_polyglot_util_NestedMap__24EntrySet$sub_refs;
typedef struct _jc_polyglot_util_NestedMap__24EntrySet$sub_nonrefs	_jc_polyglot_util_NestedMap__24EntrySet$sub_nonrefs;
typedef struct _jc_polyglot_util_NestedMap__24EntrySet$refs	_jc_polyglot_util_NestedMap__24EntrySet$refs;
typedef struct _jc_polyglot_util_NestedMap__24EntrySet$nonrefs	_jc_polyglot_util_NestedMap__24EntrySet$nonrefs;
typedef struct _jc_polyglot_util_NestedMap__24EntrySet$object	_jc_polyglot_util_NestedMap__24EntrySet$object;

typedef const struct _jc_polyglot_util_NestedMap__24EntrySet$vmethods	_jc_polyglot_util_NestedMap__24EntrySet$vmethods;
typedef const struct _jc_polyglot_util_NestedMap__24EntrySet$vtable	_jc_polyglot_util_NestedMap__24EntrySet$vtable;
typedef const struct _jc_polyglot_util_NestedMap__24EntrySet$vtype	_jc_polyglot_util_NestedMap__24EntrySet$vtype;

// Constructors
extern void _jc_polyglot_util_NestedMap__24EntrySet$method$_init$e86507e3abc60b21(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *, struct _jc_polyglot_util_NestedMap$object *);
extern void _jc_polyglot_util_NestedMap__24EntrySet$method$_init$05df9187f094598a(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *, struct _jc_polyglot_util_NestedMap$object *, struct _jc_polyglot_util_NestedMap__241$object *);

// Virtual methods
extern jboolean _jc_polyglot_util_NestedMap__24EntrySet$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_polyglot_util_NestedMap__24EntrySet$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *);
extern jboolean _jc_polyglot_util_NestedMap__24EntrySet$method$remove$d21babbbb7fafe72(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_polyglot_util_NestedMap__24EntrySet$method$size$345df5220fc60ade(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_NestedMap__24EntrySet$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_polyglot_util_NestedMap__24EntrySet$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_polyglot_util_NestedMap__24EntrySet$method_info$remove$d21babbbb7fafe72;
extern _jc_method _jc_polyglot_util_NestedMap__24EntrySet$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_polyglot_util_NestedMap__24EntrySet$vmethods {
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *);
	jboolean	(*remove$d21babbbb7fafe72)(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *, struct _jc_java_lang_Object$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *);
};

// Vtable
struct _jc_polyglot_util_NestedMap__24EntrySet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_polyglot_util_NestedMap__24EntrySet$vmethods	polyglot_util_NestedMap__24EntrySet;
};

// Vtype
struct _jc_polyglot_util_NestedMap__24EntrySet$vtype {
	_jc_type			type;
	_jc_polyglot_util_NestedMap__24EntrySet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_NestedMap__24EntrySet$sub_refs {
	struct _jc_polyglot_util_NestedMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_util_NestedMap__24EntrySet$refs {
    _jc_polyglot_util_NestedMap__24EntrySet$sub_refs	polyglot_util_NestedMap__24EntrySet;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_NestedMap__24EntrySet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_NestedMap__24EntrySet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_polyglot_util_NestedMap__24EntrySet$sub_nonrefs	polyglot_util_NestedMap__24EntrySet;
};

// Object instance structure
struct _jc_polyglot_util_NestedMap__24EntrySet$object {
	_jc_polyglot_util_NestedMap__24EntrySet$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_NestedMap__24EntrySet$vtype	*vtype;
	_jc_polyglot_util_NestedMap__24EntrySet$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_NestedMap__24EntrySet$vtype _jc_polyglot_util_NestedMap__24EntrySet$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_NestedMap__24EntrySet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_NestedMap__24EntrySet$class_object;

#endif	/* _JC_polyglot_util_NestedMap__24EntrySet_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/NestedMap__24EntrySet.h <==
// final class polyglot.util.NestedMap$EntrySet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class 2a538e5e1e2cef04 polyglot_util_NestedMap__24EntrySet

// header file dependencies
// @dep_header java_util_AbstractSet

#include "java/util/AbstractSet.h"

#ifndef _JC_polyglot_util_NestedMap__24EntrySet_H_
#define _JC_polyglot_util_NestedMap__24EntrySet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;
struct _jc_polyglot_util_NestedMap$object;
struct _jc_polyglot_util_NestedMap__241$object;

// Typedefs
typedef struct _jc_polyglot_util_NestedMap__24EntrySet$sub_refs	_jc_polyglot_util_NestedMap__24EntrySet$sub_refs;
typedef struct _jc_polyglot_util_NestedMap__24EntrySet$sub_nonrefs	_jc_polyglot_util_NestedMap__24EntrySet$sub_nonrefs;
typedef struct _jc_polyglot_util_NestedMap__24EntrySet$refs	_jc_polyglot_util_NestedMap__24EntrySet$refs;
typedef struct _jc_polyglot_util_NestedMap__24EntrySet$nonrefs	_jc_polyglot_util_NestedMap__24EntrySet$nonrefs;
typedef struct _jc_polyglot_util_NestedMap__24EntrySet$object	_jc_polyglot_util_NestedMap__24EntrySet$object;

typedef const struct _jc_polyglot_util_NestedMap__24EntrySet$vmethods	_jc_polyglot_util_NestedMap__24EntrySet$vmethods;
typedef const struct _jc_polyglot_util_NestedMap__24EntrySet$vtable	_jc_polyglot_util_NestedMap__24EntrySet$vtable;
typedef const struct _jc_polyglot_util_NestedMap__24EntrySet$vtype	_jc_polyglot_util_NestedMap__24EntrySet$vtype;

// Constructors
extern void _jc_polyglot_util_NestedMap__24EntrySet$method$_init$e86507e3abc60b21(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *, struct _jc_polyglot_util_NestedMap$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_NestedMap__24EntrySet$method$_init$05df9187f094598a(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *, struct _jc_polyglot_util_NestedMap$object *, struct _jc_polyglot_util_NestedMap__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_util_NestedMap__24EntrySet$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_util_NestedMap__24EntrySet$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_util_NestedMap__24EntrySet$method$remove$d21babbbb7fafe72(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_util_NestedMap__24EntrySet$method$size$345df5220fc60ade(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_NestedMap__24EntrySet$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_polyglot_util_NestedMap__24EntrySet$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_polyglot_util_NestedMap__24EntrySet$method_info$remove$d21babbbb7fafe72;
extern _jc_method _jc_polyglot_util_NestedMap__24EntrySet$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_polyglot_util_NestedMap__24EntrySet$vmethods {
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *) _JC_JCNI_ATTR;
	jboolean	(*remove$d21babbbb7fafe72)(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_polyglot_util_NestedMap__24EntrySet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_NestedMap__24EntrySet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_polyglot_util_NestedMap__24EntrySet$vmethods	polyglot_util_NestedMap__24EntrySet;
};

// Vtype
struct _jc_polyglot_util_NestedMap__24EntrySet$vtype {
	_jc_type			type;
	_jc_polyglot_util_NestedMap__24EntrySet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_NestedMap__24EntrySet$sub_refs {
	struct _jc_polyglot_util_NestedMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_util_NestedMap__24EntrySet$refs {
    _jc_polyglot_util_NestedMap__24EntrySet$sub_refs	polyglot_util_NestedMap__24EntrySet;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_NestedMap__24EntrySet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_NestedMap__24EntrySet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_polyglot_util_NestedMap__24EntrySet$sub_nonrefs	polyglot_util_NestedMap__24EntrySet;
};

// Object instance structure
struct _jc_polyglot_util_NestedMap__24EntrySet$object {
	_jc_polyglot_util_NestedMap__24EntrySet$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_NestedMap__24EntrySet$vtype	*vtype;
	_jc_polyglot_util_NestedMap__24EntrySet$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_NestedMap__24EntrySet$vtype _jc_polyglot_util_NestedMap__24EntrySet$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_NestedMap__24EntrySet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_NestedMap__24EntrySet$class_object;

#endif	/* _JC_polyglot_util_NestedMap__24EntrySet_H_ */
